@@ -16,7 +16,7 @@
 # sites.get moves one GRASS 5.0 sites file to a data frame, returning
 # the filled object. 
 #
-sites.get <- function(G, slist = "", debug=FALSE) {
+sites.get <- function(G, slist = "", all.sites=FALSE, debug=FALSE) {
 	if (class(G) != "grassmeta") stop("No GRASS metadata object")
 	if (! is.character(slist))
 		stop("character GRASS data base file name required")
@@ -27,8 +27,11 @@ sites.get <- function(G, slist = "", debug=FALSE) {
 		print(slist[res == FALSE])
 		stop("transfer terminated")
 	}
+	if (all.sites) allsites <- " -a"
+	else allsites <- ""
 	FILE <- tempfile("GRtoR")
-	system(paste("s.out.ascii -d sites=", slist, " > ", FILE, sep=""))
+	system(paste("s.out.ascii -d", allsites, " sites=", slist,
+		" > ", FILE, sep=""))
 	data <- read.table(FILE, na.strings="*")
 	# CHANGE 000329 RSB Only expect eastings and northings, not id as before
 	nc2 <- ncol(data) - 2
